from sqlalchemy.exc import IntegrityError, SQLAlchemyError

from models.member import Member

from utils.database import DatabaseManager

from utils.errors.database.database_error import DatabaseError
from utils.errors.database.duplicate_entry_error import DuplicateEntryError

def create_new_member(new_member: Member):
    try:
        with DatabaseManager.get_session() as session:
            session.add(new_member)
            session.commit()
    except IntegrityError as e:
        print(e)
        session.rollback()
        raise DuplicateEntryError from e
    except SQLAlchemyError as e:
        print(e)
        session.rollback()
        raise DatabaseError from e

